from setuptools import find_packages, setup

setup(
    name='cv_dice_detection',
    packages=find_packages(),
    version='0.1.0',
    description='An API developed to identify and sum the values of the total dices.',
    author='Arthur Chieppe, Luiza Valezim, Vinicius Eller',
    license='MIT',
    zip=False
)
